diff options
| author | Claudius "keldu" Holeksa <mail@keldu.de> | 2026-08-11 09:56:36 +0200 |
|---|---|---|
| committer | Claudius "keldu" Holeksa <mail@keldu.de> | 2026-08-11 09:56:36 +0200 |
| commit | 0d15416f60491bd4d17bd8b45a9487c98b8132b0 (patch) | |
| tree | fd62056148c796b1d8aa29d7c256d63e41404ff4 /examples/moving_poiseulle_particles_2d_fplbm_gpu/sim.cpp | |
| parent | 9cc16e97489860ef1989c1bb16745a4dc0155b9f (diff) | |
| parent | 792e3a52a7e0839905837c031a027b917b36a241 (diff) | |
| download | libs-lbm-0d15416f60491bd4d17bd8b45a9487c98b8132b0.tar.gz | |
Diffstat (limited to 'examples/moving_poiseulle_particles_2d_fplbm_gpu/sim.cpp')
| -rw-r--r-- | examples/moving_poiseulle_particles_2d_fplbm_gpu/sim.cpp | 13 |
1 files changed, 11 insertions, 2 deletions
diff --git a/examples/moving_poiseulle_particles_2d_fplbm_gpu/sim.cpp b/examples/moving_poiseulle_particles_2d_fplbm_gpu/sim.cpp index 328f6e2..cc7649a 100644 --- a/examples/moving_poiseulle_particles_2d_fplbm_gpu/sim.cpp +++ b/examples/moving_poiseulle_particles_2d_fplbm_gpu/sim.cpp @@ -6,6 +6,7 @@ #include <forstio/remote/filesystem/easy.hpp> #include <forstio/codec/json/json.hpp> #include <forstio/codec/simple.hpp> +#include <forstio/codec/args.hpp> namespace kel { namespace lbm { @@ -18,6 +19,14 @@ constexpr uint64_t particle_amount = 1ul; namespace sch { using namespace saw::schema; +using LbmArgs = Args< + Struct< + Member<String, "name">, + Member<UInt64, "sub_steps"> + >, + Tuple<> +>; + using InfoChunk = Chunk<UInt8, 0u, dim_x, dim_y>; template<typename T, typename Desc> @@ -185,7 +194,7 @@ saw::error_or<void> step( }).wait(); q.submit([&](acpp::sycl::handler& h){ - component<T,Desc,cmpt::FpLbmOneParticleImplicit,encode::Sycl<saw::encode::Native>> fplbm_one_part; + component<T,Desc,cmpt::FpLbmOneParticle,encode::Sycl<saw::encode::Native>> fplbm_one_part; h.parallel_for(acpp::sycl::range<1u>{particle_amount}, [=](acpp::sycl::id<1u> idx){ saw::data<sch::FixedArray<sch::UInt64,1u>> index; @@ -193,7 +202,7 @@ saw::error_or<void> step( index.at({{i}}).set(idx[i]); } - fplbm_one_part.apply(fields,macros,particles,index,t_i,{16u}); + fplbm_one_part.apply(fields,macros,particles,index,t_i,{64u}); }); }).wait(); |
